@@ -43,7 +43,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -56,7 +56,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -64,7 +64,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-cn:s3-outposts:cn-north-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -72,7 +72,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -85,7 +85,7 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
@@ -98,16 +98,16 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
+    },
+    {
+        'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
+        'region': 'fips-us-gov-east-1',
+        'config': {'s3': {'use_arn_region': True}},
+        'assertions': {
+            'exception': 'UnsupportedS3ControlArnError',
+        },
     },
-    # {
-    #    'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
-    #    'region': 'fips-us-gov-east-1',
-    #    'config': {'s3': {'use_arn_region': True}},
-    #    'assertions': {
-    #        'exception': 'UnsupportedS3ArnError',
-    #    }
-    # },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
         'region': 'us-gov-east-1-fips',
@@ -119,39 +119,39 @@ ACCESSPOINT_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
         'config': {'s3': {'use_dualstack_endpoint': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:accesspoint:myaccesspoint',
         'config': {'s3': {'use_accelerate_endpoint': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:myaccesspoint',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
 ]
 
@@ -169,7 +169,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -182,7 +182,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -190,7 +190,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': False}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-cn:s3-outposts:cn-north-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -198,7 +198,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -211,7 +211,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -224,7 +224,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:fips-us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -232,7 +232,7 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_arn_region': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws-us-gov:s3-outposts:us-gov-east-1:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -245,7 +245,7 @@ BUCKET_ARN_TEST_CASES = [
                 'x-amz-outpost-id': 'op-01234567890123456',
                 'x-amz-account-id': '123456789012',
             },
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:bucket:mybucket',
@@ -253,31 +253,31 @@ BUCKET_ARN_TEST_CASES = [
         'config': {'s3': {'use_dualstack_endpoint': True}},
         'assertions': {
             'exception': 'UnsupportedS3ControlConfigurationError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:bucket',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
     {
         'arn': 'arn:aws:s3-outposts:us-west-2:123456789012:outpost:op-01234567890123456:bucket',
         'assertions': {
             'exception': 'UnsupportedS3ControlArnError',
-        }
+        },
     },
 ]
 
@@ -368,9 +368,10 @@ def _assert_test_case(test_case, client, stubber):
             raise RuntimeError(
                 'Expected exception "%s" was not raised' % exception_cls
             )
-        error_msg = (
-            'Expected exception "%s", got "%s"'
-        ) % (exception_cls, type(exception_raised))
+        error_msg = ('Expected exception "%s", got "%s"') % (
+            exception_cls,
+            type(exception_raised),
+        )
         assert isinstance(exception_raised, exception_cls), error_msg
     else:
         assert len(stubber.requests) == 1
